@@ -2,8 +2,11 @@ import hashlib
 import os
 
 from pytgcalls import PyTgCalls
+from pyrogram.utils import MAX_CHANNEL_ID
 
 from .exceptions import NotInCall
+from .utils import queues
+from .utils.queues import que, group_call_que
 
 
 class WrapperBase:
@@ -22,6 +25,19 @@ class WrapperBase:
         if not os.path.isdir(raw_dir):
             os.mkdir(raw_dir)
 
+    def _on_stream_end(self, context, *args):
+        chat_id = MAX_CHANNEL_ID - context.full_chat.id
+        queues.task_done(chat_id)
+
+        if queues.is_empty(chat_id):
+            await self.pytgcalls.leave_group_call(chat_id)
+        else:
+            que[chat_id].pop(0)
+            try:
+                self.pytgcalls.change_stream(chat_id, queues.get(chat_id)["file"])
+            except Exception as Exc:
+                print(Exc)
+
     def _get_output(self, input: str) -> str:
         return os.path.join(self.raw_dir,  hashlib.md5(input.encode()).hexdigest())
 
